==> mcp_server_twelve_data-0.1.31.tar.gz: mcp_server_twelve_data-0.1.31/test/endpoint_pairs.py <==
pairs_ = [

    # ('Show me batches for AAPL.', 'advanced'),  # skipped-error,
    # ('Show me technical indicators interface for AAPL.', 'GetTechnicalIndicators'),  # skipped-error, fixed-manually
    ('Show me ad for AAPL.', 'GetTimeSeriesAd'),
]

pairs = [
    ('Give me the accumulation/distribution indicator for AAPL.', 'GetTimeSeriesAd'),
    ('Show me add for AAPL.', 'GetTimeSeriesAdd'),
    ('Show me adosc for AAPL.', 'GetTimeSeriesAdOsc'),
    ('Show me adx for AAPL.', 'GetTimeSeriesAdx'),
    ("Show me the Average Directional Movement Index Rating (ADXR) time series for AAPL.", "GetTimeSeriesAdxr"),
    ('Show me analyst ratings - light for AAPL.', 'GetAnalystRatingsLight'),
    ('Show me analyst ratings - us equities for AAPL.', 'GetAnalystRatingsUsEquities'),
    ('How many API requests have I made in the last minute', 'GetApiUsage'),
    ('Show me apo for AAPL.', 'GetTimeSeriesApo'),
    ('Show me aroon for AAPL.', 'GetTimeSeriesAroon'),

    ('Show me aroonosc for AAPL.', 'GetTimeSeriesAroonOsc'),
    ('Show me atr for AAPL.', 'GetTimeSeriesAtr'),
    ('Show me avg for AAPL.', 'GetTimeSeriesAvg'),
    ('Show me avgprice for AAPL.', 'GetTimeSeriesAvgPrice'),
    ('Show me balance sheet for AAPL.', 'GetBalanceSheet'),
    ('Show me balance sheet consolidated for AAPL.', 'GetBalanceSheetConsolidated'),
    # ('Show me batches for AAPL.', 'advanced'),  # skipped-error,
    ('Show me bbands for AAPL.', 'GetTimeSeriesBBands'),
    ('Show me beta for AAPL.', 'GetTimeSeriesBeta'),
    ('Show me bonds list for AAPL.', 'GetBonds'),

    ('Show me bop for AAPL.', 'GetTimeSeriesBop'),
    ('Show me cash flow for AAPL.', 'GetCashFlow'),
    ('Show me cash flow consolidated for AAPL.', 'GetCashFlowConsolidated'),
    ('Show me cci for AAPL.', 'GetTimeSeriesCci'),
    ('Show me ceil for AAPL.', 'GetTimeSeriesCeil'),
    ('Show me cmo for AAPL.', 'GetTimeSeriesCmo'),
    ('Show me commodities list for AAPL.', 'GetCommodities'),
    ('Show me coppock for AAPL.', 'GetTimeSeriesCoppock'),
    ('Show me correl for AAPL.', 'GetTimeSeriesCorrel'),
    ('Show me countries list for AAPL.', 'GetCountries'),

    ('Show me cross listings for AAPL.', 'GetCrossListings'),
    ('Show me crsi for AAPL.', 'GetTimeSeriesCrsi'),
    ('Show me cryptocurrencies list for BTC/USD.', 'GetCryptocurrencies'),
    ('Show me cryptocurrency exchanges', 'GetCryptocurrencyExchanges'),
    ('Show me currency conversion for EUR/USD.', 'GetCurrencyConversion'),
    ('Show me dema for AAPL.', 'GetTimeSeriesDema'),
    ('Show me direct holders for AAPL.', 'GetDirectHolders'),
    ('Calculate DIV indicator for AAPL.', 'GetTimeSeriesDiv'),
    ('Show me dividends for AAPL.', 'GetDividends'),
    ('Show me dividends calendar for AAPL.', 'GetDividendsCalendar'),

    ('Show me dpo for AAPL.', 'GetTimeSeriesDpo'),
    ('Show me dx for AAPL.', 'GetTimeSeriesDx'),
    ('Show me earliest timestamp for AAPL.', 'GetEarliestTimestamp'),
    ('Show me earnings for AAPL.', 'GetEarnings'),
    ('Show me earnings calendar for AAPL.', 'GetEarningsCalendar'),
    ('Show me earnings estimate for AAPL.', 'GetEarningsEstimate'),
    ('Show me edgar filings archive for AAPL.', 'GetEdgarFilingsArchive'),
    ('Show me ema for AAPL.', 'GetTimeSeriesEma'),
    ('Show me end of day price for AAPL.', 'GetEod'),
    ('Show me eps revisions for AAPL.', 'GetEpsRevisions'),

    ('Show me eps trend for AAPL.', 'GetEpsTrend'),
    ('Show me ETFs for SPY on NYSE.', 'GetEtf'),
    ('Show me ETFs in the same family as SPY.', 'GetETFsFamily'),
    ("Show me the full list of bond-type exchange-traded funds issued by BlackRock investment company.", "GetETFsList"),
    ('Show me ETF types available in the United States.', 'GetETFsType'),
    ("Give me a complete ETF analysis report for IVV, with all metrics like performance,"
     " summary, volatility, sector weights and country allocations.", "GetETFsWorld"),
    ("Show me the portfolio composition of ETF IVV.", "GetETFsWorldComposition"),
    ("Show me performance for the iShares Core S&P 500 ETF.", "GetETFsWorldPerformance"),
    ("Show me the risk metrics for the iShares Core S&P 500 ETF.", "GetETFsWorldRisk"),
    ('Show me a summary for the SPY ETF.', 'GetETFsWorldSummary'),

    ('Show me the exchange rate from USD to EUR.', 'GetExchangeRate'),
    ('Show me exchange schedule for AAPL.', 'GetExchangeSchedule'),
    ('Show me the list of available exchanges.', 'GetExchanges'),
    ('Show me exp for AAPL.', 'GetTimeSeriesExp'),
    ('Show me floor for AAPL.', 'GetTimeSeriesFloor'),
    ('Show me all available forex trading pairs.', 'GetForexPairs'),
    ('Show me fund holders for AAPL.', 'GetFundHolders'),
    ('Show me funds list for AAPL.', 'GetFunds'),
    ('Show me growth estimates for AAPL.', 'GetGrowthEstimates'),
    ('Show me heikinashicandles for AAPL.', 'GetTimeSeriesHeikinashiCandles'),

    ('Show me hlc3 for AAPL.', 'GetTimeSeriesHlc3'),
    ('Show me ht_dcperiod for AAPL.', 'GetTimeSeriesHtDcPeriod'),
    ('Show me ht_dcphase for AAPL.', 'GetTimeSeriesHtDcPhase'),
    ('Show me ht_phasor for AAPL.', 'GetTimeSeriesHtPhasor'),
    ('Show me ht_sine for AAPL.', 'GetTimeSeriesHtSine'),
    ('Show me ht_trendline for AAPL.', 'GetTimeSeriesHtTrendline'),
    ('Show me ht_trendmode for AAPL.', 'GetTimeSeriesHtTrendMode'),
    ('Show me ichimoku for AAPL.', 'GetTimeSeriesIchimoku'),
    ('Show me income statement for AAPL.', 'GetIncomeStatement'),
    ('Show me income statement consolidated for AAPL.', 'GetIncomeStatementConsolidated'),

    ('Show me insider transactions for AAPL.', 'GetInsiderTransactions'),
    ('Show me institutional holders for AAPL.', 'GetInstitutionalHolders'),
    ('Show me instrument type for AAPL.', 'GetInstrumentType'),
    ('Show me the list of available time intervals.', 'GetIntervals'),
    ('Show me the IPO calendar for upcoming companies.', 'GetIpoCalendar'),
    ('Show me kama for AAPL.', 'GetTimeSeriesKama'),
    ('Show me keltner for AAPL.', 'GetTimeSeriesKeltner'),
    ('Show me key executives for AAPL.', 'GetKeyExecutives'),
    ('Show me kst for AAPL.', 'GetTimeSeriesKst'),
    ('Show me last changes for AAPL.', 'GetLastChanges'),

    ('Show me linearreg for AAPL.', 'GetTimeSeriesLinearReg'),
    ('Show me linearregangle for AAPL.', 'GetTimeSeriesLinearRegAngle'),
    ('Show me linearregintercept for AAPL.', 'GetTimeSeriesLinearRegIntercept'),
    ('Show me linearregslope for AAPL.', 'GetTimeSeriesLinearRegSlope'),
    ('Show me ln for AAPL.', 'GetTimeSeriesLn'),
    ('Show me log10 for AAPL.', 'GetTimeSeriesLog10'),
    ('Show me logo for AAPL.', 'GetLogo'),
    ('Show me ma for AAPL.', 'GetTimeSeriesMa'),
    ('Show me macd for AAPL.', 'GetTimeSeriesMacd'),
    ('Show me macd slope for AAPL.', 'GetTimeSeriesMacdSlope'),

    ('Show me macdext for AAPL.', 'GetTimeSeriesMacdExt'),
    ('Show me mama for AAPL.', 'GetTimeSeriesMama'),
    ('Show me market capitalization for AAPL.', 'GetMarketCap'),
    ("Show me the top market movers in the US stock market.", "GetMarketMovers"),
    ("Is the NASDAQ market currently open?", "GetMarketState"),
    ('Show me max for AAPL.', 'GetTimeSeriesMax'),
    ('Show me maxindex for AAPL.', 'GetTimeSeriesMaxIndex'),
    ('Show me mcginley_dynamic for AAPL.', 'GetTimeSeriesMcGinleyDynamic'),
    ('Show me medprice for AAPL.', 'GetTimeSeriesMedPrice'),

    ('Show me mfi for AAPL.', 'GetTimeSeriesMfi'),
    ("Show me the MIDPOINT indicator for AAPL", 'GetTimeSeriesMidPoint'),
    ('Show me midprice for AAPL.', 'GetTimeSeriesMidPrice'),
    ('Show me min for AAPL.', 'GetTimeSeriesMin'),
    ('Show me minimal price index for AAPL.', 'GetTimeSeriesMinIndex'),
    ('Show me minmax for AAPL.', 'GetTimeSeriesMinMax'),
    ('Show me minmaxindex for AAPL.', 'GetTimeSeriesMinMaxIndex'),
    ('Show me minus_di for AAPL.', 'GetTimeSeriesMinusDI'),
    ('Show me minus_dm for AAPL.', 'GetTimeSeriesMinusDM'),
    ('Show me mom for AAPL.', 'GetTimeSeriesMom'),

    ('Show me mult for AAPL.', 'GetTimeSeriesMult'),
    ('Show me mutual fonds family list.', 'GetMutualFundsFamily'),
    ('Show me mutual fonds list.', 'GetMutualFundsList'),
    ('Show me mutual fonds type list.', 'GetMutualFundsType'),
    ('Show me all data for mutual fund ABCDX.', 'GetMutualFundsWorld'),
    ('Show me composition for mutual fund ABCDX.', 'GetMutualFundsWorldComposition'),
    ('Show me performance for mutual fund ABCDX.', 'GetMutualFundsWorldPerformance'),
    ('Show me purchase info for mutual fund ABCDX.', 'GetMutualFundsWorldPurchaseInfo'),
    ('Show me ratings for mutual fund ABCDX.', 'GetMutualFundsWorldRatings'),
    ('Show me risk for mutual fund ABCDX.', 'GetMutualFundsWorldRisk'),

    ('Show me summary for mutual fund ABCDX.', 'GetMutualFundsWorldSummary'),
    ('Show me sustainability for mutual fund ABCDX.', 'GetMutualFundsWorldSustainability'),
    ('Show me natr indicator for AAPL.', 'GetTimeSeriesNatr'),
    ('Show me obv indicator for AAPL.', 'GetTimeSeriesObv'),
    ('Show me percent B indicator for AAPL.', 'GetTimeSeriesPercent_B'),
    ('Show me pivot points HL for AAPL.', 'GetTimeSeriesPivotPointsHL'),
    ('Show me plus DI indicator for AAPL.', 'GetTimeSeriesPlusDI'),
    ('Show me plus DM indicator for AAPL.', 'GetTimeSeriesPlusDM'),
    ('Show me PPO indicator for AAPL.', 'GetTimeSeriesPpo'),
    ('Show me real-time price for AAPL.', 'GetPrice'),

    ('Show me price target for AAPL.', 'GetPriceTarget'),
    ('Show me company profile for AAPL.', 'GetProfile'),
    ('Show me real-time quote for AAPL.', 'GetQuote'),
    ('Show me analyst recommendations for AAPL.', 'GetRecommendations'),
    ('Show me revenue estimate for AAPL.', 'GetRevenueEstimate'),
    ('Show me ROC indicator for AAPL.', 'GetTimeSeriesRoc'),
    ('Show me ROCP indicator for AAPL.', 'GetTimeSeriesRocp'),
    ('Show me ROCR indicator for AAPL.', 'GetTimeSeriesRocr'),
    ('Show me ROCR100 indicator for AAPL.', 'GetTimeSeriesRocr100'),
    ('Show me RSI indicator for AAPL.', 'GetTimeSeriesRsi'),

    ('Show me RVOL indicator for AAPL.', 'GetTimeSeriesRvol'),
    ('Show me sanctioned entities related to AAPL.', 'GetSourceSanctionedEntities'),
    ('Show me SAR indicator for AAPL.', 'GetTimeSeriesSar'),
    ('Show me extended SAR indicator for AAPL.', 'GetTimeSeriesSarExt'),
    ('Show me SMA indicator for AAPL.', 'GetTimeSeriesSma'),
    ('Show me stock splits for AAPL.', 'GetSplits'),
    ('Show me splits calendar for AAPL.', 'GetSplitsCalendar'),
    ('Show me SQRT indicator for AAPL.', 'GetTimeSeriesSqrt'),
    ('Show me statistics for AAPL.', 'GetStatistics'),
    ('Show me standard deviation for AAPL.', 'GetTimeSeriesStdDev'),

    ('Show me stoch for AAPL.', 'GetTimeSeriesStoch'),
    ('Show me stochf for AAPL.', 'GetTimeSeriesStochF'),
    ('Show me stochrsi for AAPL.', 'GetTimeSeriesStochRsi'),
    ('Show me stocks list for AAPL.', 'GetStocks'),
    ('Show me sub for AAPL.', 'GetTimeSeriesSub'),
    ('Show me sum for AAPL.', 'GetTimeSeriesSum'),
    ('Show me supertrend for AAPL.', 'GetTimeSeriesSuperTrend'),
    ('Show me supertrend heikinashicandles for AAPL.', 'GetTimeSeriesSuperTrendHeikinAshiCandles'),
    ('Show me symbol search for AAPL.', 'GetSymbolSearch'),
    ('Show me t3ma for AAPL.', 'GetTimeSeriesT3ma'),

    ('Show me tax information for AAPL.', 'GetTaxInfo'),
    ('Show me technical indicators interface for AAPL.', 'GetTechnicalIndicators'),
    ('Show me tema for AAPL.', 'GetTimeSeriesTema'),
    ('Show me time series for AAPL.', 'GetTimeSeries'),
    ('Get cross rate time series for USD/BTC', 'GetTimeSeriesCross'),
    ('Show me trange for AAPL.', 'GetTimeSeriesTRange'),
    ('Show me trima for AAPL.', 'GetTimeSeriesTrima'),
    ('Show me tsf for AAPL.', 'GetTimeSeriesTsf'),
    ('Show me typprice for AAPL.', 'GetTimeSeriesTypPrice'),
    ('Show me ultosc for AAPL.', 'GetTimeSeriesUltOsc'),

    ('Show me var for AAPL.', 'GetTimeSeriesVar'),
    ('Show me vwap for AAPL.', 'GetTimeSeriesVwap'),
    ('Show me wclprice for AAPL.', 'GetTimeSeriesWclPrice'),
    ('Show me willr for AAPL.', 'GetTimeSeriesWillR'),
    ('Show me wma for AAPL.', 'GetTimeSeriesWma'),
]

==> mcp_server_twelve_data-0.1.40.tar.gz: mcp_server_twelve_data-0.1.40/test/endpoint_pairs.py <==
pairs_ = [
    # ('Show me batches for AAPL.', 'advanced'),  # skipped-error,
    ('Tell me the last update time for Apple’s income statement?', 'GetLastChanges'),
]

pairs = [
    ('Give me the accumulation/distribution indicator for AAPL.', 'GetTimeSeriesAd'),
    ('Show me add for AAPL.', 'GetTimeSeriesAdd'),
    ('Show me adosc for AAPL.', 'GetTimeSeriesAdOsc'),
    ('Show me adx for AAPL.', 'GetTimeSeriesAdx'),
    ("Show me the Average Directional Movement Index Rating (ADXR) time series for AAPL.", "GetTimeSeriesAdxr"),
    ('Show me analyst ratings - light for AAPL.', 'GetAnalystRatingsLight'),
    ('Show me analyst ratings - us equities for AAPL.', 'GetAnalystRatingsUsEquities'),
    ('How many API requests have I made in the last minute', 'GetApiUsage'),
    ('Show me apo for AAPL.', 'GetTimeSeriesApo'),
    ('Show me aroon for AAPL.', 'GetTimeSeriesAroon'),

    ('Show me aroonosc for AAPL.', 'GetTimeSeriesAroonOsc'),
    ('Show me atr for AAPL.', 'GetTimeSeriesAtr'),
    ('Show me avg for AAPL.', 'GetTimeSeriesAvg'),
    ('Show me avgprice for AAPL.', 'GetTimeSeriesAvgPrice'),
    ('Show me balance sheet for AAPL.', 'GetBalanceSheet'),
    ('Show me balance sheet consolidated for AAPL.', 'GetBalanceSheetConsolidated'),
    # ('Show me batches for AAPL.', 'advanced'),  # skipped-error,
    ('Show me bbands for AAPL.', 'GetTimeSeriesBBands'),
    ('Show me beta for AAPL.', 'GetTimeSeriesBeta'),
    ('Show me bonds list for AAPL.', 'GetBonds'),

    ('Show me bop for AAPL.', 'GetTimeSeriesBop'),
    ('Show me cash flow for AAPL.', 'GetCashFlow'),
    ('Show me cash flow consolidated for AAPL.', 'GetCashFlowConsolidated'),
    ('Show me cci for AAPL.', 'GetTimeSeriesCci'),
    ('Show me ceil for AAPL.', 'GetTimeSeriesCeil'),
    ('Show me cmo for AAPL.', 'GetTimeSeriesCmo'),
    ('Show me commodities list for AAPL.', 'GetCommodities'),
    ('Show me coppock for AAPL.', 'GetTimeSeriesCoppock'),
    ('Show me correl for AAPL.', 'GetTimeSeriesCorrel'),
    ('Show me countries list for AAPL.', 'GetCountries'),

    ('Show me cross listings for AAPL.', 'GetCrossListings'),
    ('Show me crsi for AAPL.', 'GetTimeSeriesCrsi'),
    ('Show me cryptocurrencies list for BTC/USD.', 'GetCryptocurrencies'),
    ('Show me cryptocurrency exchanges', 'GetCryptocurrencyExchanges'),
    ('Show me currency conversion for EUR/USD.', 'GetCurrencyConversion'),
    ('Show me dema for AAPL.', 'GetTimeSeriesDema'),
    ('Show me direct holders for AAPL.', 'GetDirectHolders'),
    ('Calculate DIV indicator for AAPL.', 'GetTimeSeriesDiv'),
    ('Show me dividends for AAPL.', 'GetDividends'),
    ('Show me dividends calendar for AAPL.', 'GetDividendsCalendar'),

    ('Show me dpo for AAPL.', 'GetTimeSeriesDpo'),
    ('Show me dx for AAPL.', 'GetTimeSeriesDx'),
    ('Show me earliest timestamp for AAPL.', 'GetEarliestTimestamp'),
    ('Show me earnings for AAPL.', 'GetEarnings'),
    ('Show me earnings calendar for China for 2024 year.', 'GetEarningsCalendar'),
    ('Show me earnings estimate for AAPL.', 'GetEarningsEstimate'),
    ('Show me edgar filings archive for AAPL.', 'GetEdgarFilingsArchive'),
    ('Show me ema for AAPL.', 'GetTimeSeriesEma'),
    ('Show me end of day price for AAPL.', 'GetEod'),
    ('Show me eps revisions for AAPL.', 'GetEpsRevisions'),

    ('Show me eps trend for AAPL.', 'GetEpsTrend'),
    ('Show me ETFs for SPY on NYSE.', 'GetEtf'),
    ('Show me ETFs in the same family as SPY.', 'GetETFsFamily'),
    ("Show me the full list of bond-type exchange-traded funds issued by BlackRock investment company.", "GetETFsList"),
    ('Show me ETF types available in the United States.', 'GetETFsType'),
    ("Give me a complete ETF analysis report for IVV, with all metrics like performance,"
     " summary, volatility, sector weights and country allocations.", "GetETFsWorld"),
    ("Show me the portfolio composition of ETF IVV.", "GetETFsWorldComposition"),
    ("Show me performance for the iShares Core S&P 500 ETF.", "GetETFsWorldPerformance"),
    ("Show me the risk metrics for the iShares Core S&P 500 ETF.", "GetETFsWorldRisk"),
    ('Show me a summary for the SPY ETF.', 'GetETFsWorldSummary'),

    ('Show me the exchange rate from USD to EUR.', 'GetExchangeRate'),
    ('Show me exchange schedule for AAPL.', 'GetExchangeSchedule'),
    ('Show me the list of available exchanges.', 'GetExchanges'),
    ('Show me exp for AAPL.', 'GetTimeSeriesExp'),
    ('Show me floor for AAPL.', 'GetTimeSeriesFloor'),
    ('Show me all available forex trading pairs.', 'GetForexPairs'),
    ('Show me fund holders for AAPL.', 'GetFundHolders'),
    ('Show me funds list for AAPL.', 'GetFunds'),
    ('Show me growth estimates for AAPL.', 'GetGrowthEstimates'),
    ('Show me heikinashicandles for AAPL.', 'GetTimeSeriesHeikinashiCandles'),

    ('Show me hlc3 for AAPL.', 'GetTimeSeriesHlc3'),
    ('Show me ht_dcperiod for AAPL.', 'GetTimeSeriesHtDcPeriod'),
    ('Show me ht_dcphase for AAPL.', 'GetTimeSeriesHtDcPhase'),
    ('Show me ht_phasor for AAPL.', 'GetTimeSeriesHtPhasor'),
    ('Show me ht_sine for AAPL.', 'GetTimeSeriesHtSine'),
    ('Show me ht_trendline for AAPL.', 'GetTimeSeriesHtTrendline'),
    ('Show me ht_trendmode for AAPL.', 'GetTimeSeriesHtTrendMode'),
    ('Show me ichimoku for AAPL.', 'GetTimeSeriesIchimoku'),
    ('Show me income statement for AAPL.', 'GetIncomeStatement'),
    ('Show me income statement consolidated for AAPL.', 'GetIncomeStatementConsolidated'),

    ('Show me insider transactions for AAPL.', 'GetInsiderTransactions'),
    ('Show me institutional holders for AAPL.', 'GetInstitutionalHolders'),
    ('What types of instruments are available through the API?', 'GetInstrumentType'),
    ('Show me the list of available time intervals.', 'GetIntervals'),
    ('Show me the IPO calendar for upcoming companies.', 'GetIpoCalendar'),
    ('Show me kama for AAPL.', 'GetTimeSeriesKama'),
    ('Show me keltner for AAPL.', 'GetTimeSeriesKeltner'),
    ('Show me key executives for AAPL.', 'GetKeyExecutives'),
    ('Show me kst for AAPL.', 'GetTimeSeriesKst'),
    ('Tell me the last update time for Apple’s income statement?', 'GetLastChanges'),

    ('Show me linearreg for AAPL.', 'GetTimeSeriesLinearReg'),
    ('Show me linearregangle for AAPL.', 'GetTimeSeriesLinearRegAngle'),
    ('Show me linearregintercept for AAPL.', 'GetTimeSeriesLinearRegIntercept'),
    ('Show me linearregslope for AAPL.', 'GetTimeSeriesLinearRegSlope'),
    ('Show me ln for AAPL.', 'GetTimeSeriesLn'),
    ('Show me log10 for AAPL.', 'GetTimeSeriesLog10'),
    ('Show me logo for AAPL.', 'GetLogo'),
    ('Show me ma for AAPL.', 'GetTimeSeriesMa'),
    ('Show me macd for AAPL.', 'GetTimeSeriesMacd'),
    ('Show me macd slope for AAPL.', 'GetTimeSeriesMacdSlope'),

    ('Show me macdext for AAPL.', 'GetTimeSeriesMacdExt'),
    ('Show me mama for AAPL.', 'GetTimeSeriesMama'),
    ('Show me market capitalization for AAPL.', 'GetMarketCap'),
    ("Show me the top market movers in the US stock market.", "GetMarketMovers"),
    ("Is the NASDAQ market currently open?", "GetMarketState"),
    ('Show me max for AAPL.', 'GetTimeSeriesMax'),
    ('Show me maxindex for AAPL.', 'GetTimeSeriesMaxIndex'),
    ('Show me mcginley_dynamic for AAPL.', 'GetTimeSeriesMcGinleyDynamic'),
    ('Show me medprice for AAPL.', 'GetTimeSeriesMedPrice'),

    ('Show me mfi for AAPL.', 'GetTimeSeriesMfi'),
    ("Show me the MIDPOINT indicator for AAPL", 'GetTimeSeriesMidPoint'),
    ('Show me midprice for AAPL.', 'GetTimeSeriesMidPrice'),
    ('Show me min for AAPL.', 'GetTimeSeriesMin'),
    ('Show me minimal price index for AAPL.', 'GetTimeSeriesMinIndex'),
    ('Show me minmax for AAPL.', 'GetTimeSeriesMinMax'),
    ('Show me minmaxindex for AAPL.', 'GetTimeSeriesMinMaxIndex'),
    ('Show me minus_di for AAPL.', 'GetTimeSeriesMinusDI'),
    ('Show me minus_dm for AAPL.', 'GetTimeSeriesMinusDM'),
    ('Show me mom for AAPL.', 'GetTimeSeriesMom'),

    ('Show me mult for AAPL.', 'GetTimeSeriesMult'),
    ('Show me mutual fonds family list.', 'GetMutualFundsFamily'),
    ('Show me mutual fonds list.', 'GetMutualFundsList'),
    ('Show me mutual fonds type list.', 'GetMutualFundsType'),
    ('Show me all data for mutual fund VTSMX.', 'GetMutualFundsWorld'),
    ('Show me composition for mutual fund VTSMX.', 'GetMutualFundsWorldComposition'),
    ('Show me performance for mutual fund VTSMX.', 'GetMutualFundsWorldPerformance'),
    ('Show me purchase info for mutual fund VTSMX.', 'GetMutualFundsWorldPurchaseInfo'),
    ('Show me ratings for mutual fund VTSMX.', 'GetMutualFundsWorldRatings'),
    ('Show me risk for mutual fund VTSMX.', 'GetMutualFundsWorldRisk'),

    ('Show me summary for mutual fund VTSMX.', 'GetMutualFundsWorldSummary'),
    ('Show me sustainability for mutual fund VTSMX.', 'GetMutualFundsWorldSustainability'),
    ('Show me natr indicator for AAPL.', 'GetTimeSeriesNatr'),
    ('Show me obv indicator for AAPL.', 'GetTimeSeriesObv'),
    ('Show me percent B indicator for AAPL.', 'GetTimeSeriesPercent_B'),
    ('Show me pivot points HL for AAPL.', 'GetTimeSeriesPivotPointsHL'),
    ('Show me plus DI indicator for AAPL.', 'GetTimeSeriesPlusDI'),
    ('Show me plus DM indicator for AAPL.', 'GetTimeSeriesPlusDM'),
    ('Show me PPO indicator for AAPL.', 'GetTimeSeriesPpo'),
    ('Show me real-time price for AAPL.', 'GetPrice'),

    ('Show me price target for AAPL.', 'GetPriceTarget'),
    ('Show me company profile for AAPL.', 'GetProfile'),
    ('Show me real-time quote for AAPL.', 'GetQuote'),
    ('Show me analyst recommendations for AAPL.', 'GetRecommendations'),
    ('Show me revenue estimate for AAPL.', 'GetRevenueEstimate'),
    ('Show me ROC indicator for AAPL.', 'GetTimeSeriesRoc'),
    ('Show me ROCP indicator for AAPL.', 'GetTimeSeriesRocp'),
    ('Show me ROCR indicator for AAPL.', 'GetTimeSeriesRocr'),
    ('Show me ROCR100 indicator for AAPL.', 'GetTimeSeriesRocr100'),
    ('Show me RSI indicator for AAPL.', 'GetTimeSeriesRsi'),

    ('Show me RVOL indicator for AAPL.', 'GetTimeSeriesRvol'),
    ('List all entities sanctioned by OFAC.', 'GetSourceSanctionedEntities'),
    ('Show me SAR indicator for AAPL.', 'GetTimeSeriesSar'),
    ('Show me extended SAR indicator for AAPL.', 'GetTimeSeriesSarExt'),
    ('Show me SMA indicator for AAPL.', 'GetTimeSeriesSma'),
    ('Show me stock splits for AAPL.', 'GetSplits'),
    ('Show me splits calendar for AAPL.', 'GetSplitsCalendar'),
    ('Show me SQRT indicator for AAPL.', 'GetTimeSeriesSqrt'),
    ('Show me statistics for AAPL.', 'GetStatistics'),
    ('Show me standard deviation for AAPL.', 'GetTimeSeriesStdDev'),

    ('Show me stoch for AAPL.', 'GetTimeSeriesStoch'),
    ('Show me stochf for AAPL.', 'GetTimeSeriesStochF'),
    ('Show me stochrsi for AAPL.', 'GetTimeSeriesStochRsi'),
    ('Show me stocks list for AAPL.', 'GetStocks'),
    ('Show me sub for AAPL.', 'GetTimeSeriesSub'),
    ('Show me sum for AAPL.', 'GetTimeSeriesSum'),
    ('Show me supertrend for AAPL.', 'GetTimeSeriesSuperTrend'),
    ('Show me supertrend heikinashicandles for AAPL.', 'GetTimeSeriesSuperTrendHeikinAshiCandles'),
    ('Show me symbol search for AAPL.', 'GetSymbolSearch'),
    ('Show me t3ma for AAPL.', 'GetTimeSeriesT3ma'),

    ('Show me tax information for AAPL.', 'GetTaxInfo'),
    ('Show me technical indicators interface for AAPL.', 'GetTechnicalIndicators'),
    ('Show me tema for AAPL.', 'GetTimeSeriesTema'),
    ('Show me time series for AAPL.', 'GetTimeSeries'),
    ('Get cross rate time series for USD/BTC', 'GetTimeSeriesCross'),
    ('Show me trange for AAPL.', 'GetTimeSeriesTRange'),
    ('Show me trima for AAPL.', 'GetTimeSeriesTrima'),
    ('Show me tsf for AAPL.', 'GetTimeSeriesTsf'),
    ('Show me typprice for AAPL.', 'GetTimeSeriesTypPrice'),
    ('Show me ultosc for AAPL.', 'GetTimeSeriesUltOsc'),

    ('Show me var for AAPL.', 'GetTimeSeriesVar'),
    ('Show me vwap for AAPL.', 'GetTimeSeriesVwap'),
    ('Show me wclprice for AAPL.', 'GetTimeSeriesWclPrice'),
    ('Show me willr for AAPL.', 'GetTimeSeriesWillR'),
    ('Show me wma for AAPL.', 'GetTimeSeriesWma'),
]
